@@ -3,14 +3,15 @@
 
 # djk/pipes/tail.py
 
-from pjk.base import Pipe, ParsedToken, Usage
+from pjk.components import Pipe
+from pjk.usage import ParsedToken, Usage
 
 class TailPipe(Pipe):
     @classmethod
     def usage(cls):
         usage = Usage(
             name='tail',
-            desc='take last records of input (when single-threaded)',
+            desc='take last records of input',
             component_class=cls
         )
         usage.def_arg(name='limit', usage='number of records', is_num=True)
