@@ -3,7 +3,8 @@
 
 import importlib.util
 from typing import Optional
-from pjk.base import Source, Pipe, Sink, ParsedToken, UsageError
+from pjk.components import Source, Pipe, Sink
+from pjk.usage import ParsedToken, UsageError
 
 class UserSourceFactory:
     @staticmethod
@@ -28,6 +29,10 @@ class UserSourceFactory:
                 and value is not Source
                 and value.__module__ == module.__name__  # 🧠 only user-defined classes
             ):
-                return value(ptok)
+                
+                usage = value.usage()
+                usage.bind(ptok)
+                source = value(ptok, usage)
+                return source
 
         return None
